/*******************************************************************************
* File Name: OpAmp_Buffer.h
* Version 1.20
*
* Description:
*  This file contains the function prototypes and constants used in
*  the Opamp (Analog Buffer) Component.
*
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/


#if !defined(CY_OPAMP_OpAmp_Buffer_H)
#define CY_OPAMP_OpAmp_Buffer_H

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
*       Type Definitions
***************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} OpAmp_Buffer_BACKUP_STRUCT;


/**************************************
*        Function Prototypes
**************************************/
void OpAmp_Buffer_Init(void);
void OpAmp_Buffer_Enable(void);
void OpAmp_Buffer_Start(void);
void OpAmp_Buffer_Stop(void);
void OpAmp_Buffer_SetPower(uint32 power);
void OpAmp_Buffer_PumpControl(uint32 onOff);
void OpAmp_Buffer_Sleep(void);
void OpAmp_Buffer_Wakeup(void);
void OpAmp_Buffer_SaveConfig(void);
void OpAmp_Buffer_RestoreConfig(void);


/**************************************
*           API Constants
**************************************/

/* Parameters for SetPower() function */
#define OpAmp_Buffer_LOW_POWER      (1u)
#define OpAmp_Buffer_MED_POWER      (2u)
#define OpAmp_Buffer_HIGH_POWER     (3u)


/* Parameters for PumpControl() function */
#define OpAmp_Buffer_PUMP_ON        (1u)
#define OpAmp_Buffer_PUMP_OFF       (0u)


/***************************************
*   Initial Parameter Constants
****************************************/

#define OpAmp_Buffer_OUTPUT_CURRENT         (0u)
#define OpAmp_Buffer_POWER                  (1u)
#define OpAmp_Buffer_MODE                   (1u)
#define OpAmp_Buffer_OA_COMP_TRIM_VALUE     (3u)
#define OpAmp_Buffer_DEEPSLEEP_SUPPORT      (0u)


/***************************************
*    Variables with External Linkage
***************************************/

extern uint8  OpAmp_Buffer_initVar;


/**************************************
*             Registers
**************************************/

#ifdef CYIPBLOCK_m0s8pass4b_VERSION
    #define OpAmp_Buffer_CTB_CTRL_REG       (*(reg32 *) OpAmp_Buffer_cy_psoc4_abuf__CTB_CTB_CTRL)
    #define OpAmp_Buffer_CTB_CTRL_PTR       ( (reg32 *) OpAmp_Buffer_cy_psoc4_abuf__CTB_CTB_CTRL)
#else
    #define OpAmp_Buffer_CTB_CTRL_REG       (*(reg32 *) OpAmp_Buffer_cy_psoc4_abuf__CTBM_CTB_CTRL)
    #define OpAmp_Buffer_CTB_CTRL_PTR       ( (reg32 *) OpAmp_Buffer_cy_psoc4_abuf__CTBM_CTB_CTRL)
#endif /* CYIPBLOCK_m0s8pass4b_VERSION */

#define OpAmp_Buffer_OA_RES_CTRL_REG    (*(reg32 *) OpAmp_Buffer_cy_psoc4_abuf__OA_RES_CTRL)
#define OpAmp_Buffer_OA_RES_CTRL_PTR    ( (reg32 *) OpAmp_Buffer_cy_psoc4_abuf__OA_RES_CTRL)
#define OpAmp_Buffer_OA_COMP_TRIM_REG   (*(reg32 *) OpAmp_Buffer_cy_psoc4_abuf__OA_COMP_TRIM)
#define OpAmp_Buffer_OA_COMP_TRIM_PTR   ( (reg32 *) OpAmp_Buffer_cy_psoc4_abuf__OA_COMP_TRIM)


/***************************************
*        Registers Constants
***************************************/

/* OpAmp_Buffer_CTB_CTRL_REG */
#define OpAmp_Buffer_CTB_CTRL_DEEPSLEEP_ON_SHIFT    (30u)   /* [30] Selects behavior CTB IP in the DeepSleep power mode */
#define OpAmp_Buffer_CTB_CTRL_ENABLED_SHIFT         (31u)   /* [31] Enable of the CTB IP */


#define OpAmp_Buffer_CTB_CTRL_DEEPSLEEP_ON          ((uint32) 0x01u << OpAmp_Buffer_CTB_CTRL_DEEPSLEEP_ON_SHIFT)
#define OpAmp_Buffer_CTB_CTRL_ENABLED               ((uint32) 0x01u << OpAmp_Buffer_CTB_CTRL_ENABLED_SHIFT)


/* OpAmp_Buffer_OA_RES_CTRL_REG */
#define OpAmp_Buffer_OA_PWR_MODE_SHIFT          (0u)    /* [1:0]    Power level */
#define OpAmp_Buffer_OA_DRIVE_STR_SEL_SHIFT     (2u)    /* [2]      Opamp output strenght select: 0 - 1x, 1 - 10x */
#define OpAmp_Buffer_OA_COMP_EN_SHIFT           (4u)    /* [4]      CTB IP mode: 0 - Opamp, 1 - Comparator  */
#define OpAmp_Buffer_OA_PUMP_EN_SHIFT           (11u)   /* [11]     Pump enable */


#define OpAmp_Buffer_OA_PWR_MODE                ((uint32) 0x02u << OpAmp_Buffer_OA_PWR_MODE_SHIFT)
#define OpAmp_Buffer_OA_PWR_MODE_MASK           ((uint32) 0x03u << OpAmp_Buffer_OA_PWR_MODE_SHIFT)
#define OpAmp_Buffer_OA_DRIVE_STR_SEL_1X        ((uint32) 0x00u << OpAmp_Buffer_OA_DRIVE_STR_SEL_SHIFT)
#define OpAmp_Buffer_OA_DRIVE_STR_SEL_10X       ((uint32) 0x01u << OpAmp_Buffer_OA_DRIVE_STR_SEL_SHIFT)
#define OpAmp_Buffer_OA_DRIVE_STR_SEL_MASK      ((uint32) 0x01u << OpAmp_Buffer_OA_DRIVE_STR_SEL_SHIFT)
#define OpAmp_Buffer_OA_COMP_EN                 ((uint32) 0x00u << OpAmp_Buffer_OA_COMP_EN_SHIFT)
#define OpAmp_Buffer_OA_PUMP_EN                 ((uint32) 0x01u << OpAmp_Buffer_OA_PUMP_EN_SHIFT)


/***************************************
*       Init Macros Definitions
***************************************/

#define OpAmp_Buffer_GET_DEEPSLEEP_ON(deepSleep)    ((0u != (deepSleep)) ? (OpAmp_Buffer_CTB_CTRL_DEEPSLEEP_ON) : (0u))
#define OpAmp_Buffer_GET_OA_DRIVE_STR(current)      ((0u != (current)) ? (OpAmp_Buffer_OA_DRIVE_STR_SEL_10X) : \
                                                                             (OpAmp_Buffer_OA_DRIVE_STR_SEL_1X))
#define OpAmp_Buffer_GET_OA_PWR_MODE(mode)          ((mode) & OpAmp_Buffer_OA_PWR_MODE_MASK)
#define OpAmp_Buffer_CHECK_PWR_MODE_OFF             (0u != (OpAmp_Buffer_OA_RES_CTRL_REG & \
                                                                OpAmp_Buffer_OA_PWR_MODE_MASK))

/* Returns true if component available in Deep Sleep power mode*/ 
#define OpAmp_Buffer_CHECK_DEEPSLEEP_SUPPORT        (0u != OpAmp_Buffer_DEEPSLEEP_SUPPORT) 

#define OpAmp_Buffer_DEFAULT_CTB_CTRL (OpAmp_Buffer_GET_DEEPSLEEP_ON(OpAmp_Buffer_DEEPSLEEP_SUPPORT) | \
                                           OpAmp_Buffer_CTB_CTRL_ENABLED)

#define OpAmp_Buffer_DEFAULT_OA_RES_CTRL (OpAmp_Buffer_OA_COMP_EN | \
                                              OpAmp_Buffer_GET_OA_DRIVE_STR(OpAmp_Buffer_OUTPUT_CURRENT))

#define OpAmp_Buffer_DEFAULT_OA_COMP_TRIM_REG (OpAmp_Buffer_OA_COMP_TRIM_VALUE)


/***************************************
* The following code is DEPRECATED and 
* should not be used in new projects.
***************************************/

#define OpAmp_Buffer_LOWPOWER                   (OpAmp_Buffer_LOW_POWER)
#define OpAmp_Buffer_MEDPOWER                   (OpAmp_Buffer_MED_POWER)
#define OpAmp_Buffer_HIGHPOWER                  (OpAmp_Buffer_HIGH_POWER)

/* PUMP ON/OFF defines */
#define OpAmp_Buffer_PUMPON                     (OpAmp_Buffer_PUMP_ON)
#define OpAmp_Buffer_PUMPOFF                    (OpAmp_Buffer_PUMP_OFF)

#define OpAmp_Buffer_OA_CTRL                    (OpAmp_Buffer_CTB_CTRL_REG)
#define OpAmp_Buffer_OA_RES_CTRL                (OpAmp_Buffer_OA_RES_CTRL_REG)

/* Bit Field  OA_CTRL */
#define OpAmp_Buffer_OA_CTB_EN_SHIFT            (OpAmp_Buffer_CTB_CTRL_ENABLED_SHIFT)
#define OpAmp_Buffer_OA_PUMP_CTRL_SHIFT         (OpAmp_Buffer_OA_PUMP_EN_SHIFT)
#define OpAmp_Buffer_OA_PUMP_EN_MASK            (0x800u)
#define OpAmp_Buffer_PUMP_PROTECT_MASK          (1u)


#endif    /* CY_OPAMP_OpAmp_Buffer_H */


/* [] END OF FILE */
